@@ -2,7 +2,9 @@
 
 import os
 
-import grab
+from django.core.exceptions import ObjectDoesNotExist
+
+from grab import spider, Grab as GrabLib
 
 import defaults
 import models
@@ -14,7 +16,10 @@ USER_AGENT_FILE = os.path.join(APP_ROOT, 'data/agents.txt')
 
 def get_proxies():
     proxies = []
-    for obj in models.Proxy.objects.filter(errors=0):
+    proxies_list = models.Proxy.objects.filter(errors=0)
+    if not proxies_list.exists():
+        raise ObjectDoesNotExist('Active proxy not found!')
+    for obj in proxies_list:
         proxy = '%s:%d' % (obj.hostname, obj.port)
         if obj.user and obj.password:
             proxy += ':%s:%s' % (obj.user, obj.password)
@@ -23,7 +28,7 @@ def get_proxies():
 
 
 def Grab(**kwargs):
-    grb = grab.Grab()
+    grb = GrabLib()
     default_settings = {
         'user_agent_file': USER_AGENT_FILE,
         'connect_timeout': defaults.GRABBER_CONNECT_TIMEOUT,
@@ -41,3 +46,8 @@ def Grab(**kwargs):
         auto_change=True
     )
     return grb
+
+
+class Spider(spider.base.Spider):
+    def create_grab_instance(self):
+        return Grab(**self.grab_config)
